@@ -437,8 +437,9 @@ def extraction_chain(ocr_text, openai_key, side = ''):
         verification_function = [convert_pydantic_to_openai_function(Verify_IRQ_ID), convert_pydantic_to_openai_function(Verify_IRQ_Passport)]
         verification_model = model_verification.bind(functions=verification_function)
         verification_chain = prompt_verify_doc | verification_model | OpenAIFunctionsAgentOutputParser() | route_verification
-
+        st = time.time()
         verification_model_result = verification_chain.invoke({"ocr_text":ocr_text})
+        logging.info(f'----------------Time taken for Verification Chain: {time.time() - st} seconds\n')
         if verification_model_result == '':
             if side=='front':
                 return {'error':f'not_front_id'}, ''
@@ -459,8 +460,11 @@ def extraction_chain(ocr_text, openai_key, side = ''):
                 side_predicted = verification_model_result.get("side","")
             print("Side Predicted:", side_predicted)
 
+
+
         if is_valid_id=="True" and side==side_predicted:
             max_retries = 2
+            st = time.time()
             for attempt in range(max_retries+1):
                 extraction_chain = prompt | extraction_model | OpenAIFunctionsAgentOutputParser() | route
                 data = extraction_chain.invoke({"ocr_text": ocr_text})
@@ -488,6 +492,7 @@ def extraction_chain(ocr_text, openai_key, side = ''):
                     print("RETRYING")
                     time.sleep(2)
                     continue
+            logging.info(f'----------------Time taken for Extraction Chain: {time.time() - st} seconds\n')
 
         else:
             if side=='' or side=='auto':
