@@ -476,7 +476,10 @@ def extract_name_from_front(text, dob):
     return name.strip()
 
 def sdn_front_id_extraction(client, ar_front_id_data, image_data, texts,compressed_image):
-    front_id_data = translator.translate(ar_front_id_data, src='ar', dest='en').text
+    try:
+        front_id_data = translator.translate(ar_front_id_data, src='ar', dest='en').text
+    except Exception as e:
+        front_id_data = GoogleTranslator('ar', 'en').translate(ar_front_id_data)
     # print(f'\n\nTranslated front ID data: {front_id_data}\n')
     
     id_number_pattern = r"\b\d{11}\b"
